@@ -33,9 +33,10 @@
 #  define KPTY_DEPRECATED_NO_EXPORT KPTY_NO_EXPORT KPTY_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPTY_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPTY_NO_DEPRECATED
+#    define KPTY_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
